check_runaway_write_ts

Function check_runaway_write_ts 

pub(crate) fn check_runaway_write_ts(now: &Timestamp, timestamp: Timestamp)
Logs an error when timestamp is further ahead of now than a local write timestamp should ever be, the signal that the EpochMilliseconds timeline has run away (e.g. after a wall-clock regression).